@@ -5,6 +5,10 @@ This most likely isn't what you (a normal human) wants
 unless you have installed `https://github.com/novafacing/ubuntu-rc`
 """
 
-from pwn import context
+from logging import CRITICAL
+from pwnlib.context import context
+from pwnlib.log import console
+
 
 context.terminal = ["kitty", "-e", "sh", "-c"]  # pylint: disable=assigning-non-slot
+console.setLevel(CRITICAL)
